Improve this doc

# Error: ng:cpi
Bad Copy

    Can't copy! Source and destination are identical.

## Description

This error occurs when attempting to copy an object to itself. Calling angular.copy with a `destination` object deletes all of the elements or properties on `destination` before copying to it. Copying an object to itself is not supported. Make sure to check your calls to `angular.copy` and avoid copying objects or arrays to themselves.